recordStore.ParsingRecordStore

|  | ## Cheshire3 Object Model: Class ParsingRecordStore

Module recordStore :: Class ParsingRecordStore

## Class ParsingRecordStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                  ObjectStore --+
                                |
          baseObjects.RecordStore --+
                                    |
                    SimpleRecordStore --+
                                        |
                                       ParsingRecordStore

Known Subclasses:
  MarcRecordStore

Instance Methods

__init__(self, session, config, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
create_record(self, session, record) Create a record and assign it a new identifier.
fetch_record(self, session, id) Return the record with the given identifier.
store_record(self, session, record) Store an existing record.
begin_storing(self, session)
commit_storing(self, session)
Inherited from `SimpleRecordStore`: `delete_record`, `fetch_recordChecksum`, `fetch_recordSize`, `process_data`, `replace_record` Inherited from `baseObjects.ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

documentStore |
workflow |
Inherited from `SimpleRecordStore`: `idNormalizer`, `inTransformer`, `outParser` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, config, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: SimpleRecordStore.__init__

### create_record(self, session, record) | source code
Create a record and assign it a new identifier. Overrides: SimpleRecordStore.create_record

### fetch_record(self, session, id) | source code
Return the record with the given identifier. Overrides: SimpleRecordStore.fetch_record

### store_record(self, session, record) | source code
Store an existing record. It must already have an identifier assigned to it. Overrides: SimpleRecordStore.store_record

### begin_storing(self, session) | source code

### commit_storing(self, session) | source code

Class Variable Details

    ### documentStore Value:
        None

    ### workflow Value:
        None